@@ -5,7 +5,7 @@
 
 
 static unsigned long des_SPtrans[8][64]={
-    /* nibble 0 */
+    { /* nibble 0 */
     0x00820200, 0x00020000, 0x80800000, 0x80820200,
     0x00800000, 0x80020200, 0x80020000, 0x80800000,
     0x80020200, 0x00820200, 0x00820000, 0x80000200,
@@ -21,9 +21,9 @@ static unsigned long des_SPtrans[8][64]={
     0x80820200, 0x00020200, 0x00820000, 0x80800200,
     0x00800000, 0x80000200, 0x80020000, 0x00000000,
     0x00020000, 0x00800000, 0x80800200, 0x00820200,
-    0x80000000, 0x80820000, 0x00000200, 0x80020200,
+    0x80000000, 0x80820000, 0x00000200, 0x80020200 },
 
-    /* nibble 1 */
+    { /* nibble 1 */
     0x10042004, 0x00000000, 0x00042000, 0x10040000,
     0x10000004, 0x00002004, 0x10002000, 0x00042000,
     0x00002000, 0x10040004, 0x00000004, 0x10002000,
@@ -39,9 +39,9 @@ static unsigned long des_SPtrans[8][64]={
     0x10042000, 0x00002000, 0x00000000, 0x10000004,
     0x00000004, 0x10042004, 0x00042000, 0x10040000,
     0x10040004, 0x00040000, 0x00002004, 0x10002000,
-    0x10002004, 0x00000004, 0x10040000, 0x00042000,
+    0x10002004, 0x00000004, 0x10040000, 0x00042000 },
 
-    /* nibble 2 */
+    { /* nibble 2 */
     0x41000000, 0x01010040, 0x00000040, 0x41000040,
     0x40010000, 0x01000000, 0x41000040, 0x00010040,
     0x01000040, 0x00010000, 0x01010000, 0x40000000,
@@ -57,9 +57,9 @@ static unsigned long des_SPtrans[8][64]={
     0x40010040, 0x41000000, 0x01000000, 0x41010040,
     0x00010000, 0x01000040, 0x41000040, 0x00010040,
     0x01000040, 0x00000000, 0x41010000, 0x40000040,
-    0x41000000, 0x40010040, 0x00000040, 0x01010000,
+    0x41000000, 0x40010040, 0x00000040, 0x01010000 },
 
-    /* nibble 3 */
+    { /* nibble 3 */
     0x00100402, 0x04000400, 0x00000002, 0x04100402,
     0x00000000, 0x04100000, 0x04000402, 0x00100002,
     0x04100400, 0x04000002, 0x04000000, 0x00000402,
@@ -75,9 +75,9 @@ static unsigned long des_SPtrans[8][64]={
     0x04000000, 0x04100402, 0x00100402, 0x00100000,
     0x04100402, 0x00000002, 0x04000400, 0x00100402,
     0x00100002, 0x00100400, 0x04100000, 0x04000402,
-    0x00000402, 0x04000000, 0x04000002, 0x04100400,
+    0x00000402, 0x04000000, 0x04000002, 0x04100400 },
 
-    /* nibble 4 */
+    { /* nibble 4 */
     0x02000000, 0x00004000, 0x00000100, 0x02004108,
     0x02004008, 0x02000100, 0x00004108, 0x02004000,
     0x00004000, 0x00000008, 0x02000008, 0x00004100,
@@ -93,9 +93,9 @@ static unsigned long des_SPtrans[8][64]={
     0x02000108, 0x00000100, 0x00000000, 0x02004108,
     0x02004008, 0x02004100, 0x00000108, 0x00004000,
     0x00004100, 0x02004008, 0x02000100, 0x00000108,
-    0x00000008, 0x00004108, 0x02004000, 0x02000008,
+    0x00000008, 0x00004108, 0x02004000, 0x02000008 },
 
-    /* nibble 5 */
+    { /* nibble 5 */
     0x20000010, 0x00080010, 0x00000000, 0x20080800,
     0x00080010, 0x00000800, 0x20000810, 0x00080000,
     0x00000810, 0x20080810, 0x00080800, 0x20000000,
@@ -111,9 +111,9 @@ static unsigned long des_SPtrans[8][64]={
     0x20080810, 0x00080800, 0x00080000, 0x20000810,
     0x20000010, 0x20080000, 0x00080810, 0x00000000,
     0x00000800, 0x20000010, 0x20000810, 0x20080800,
-    0x20080000, 0x00000810, 0x00000010, 0x20080010,
+    0x20080000, 0x00000810, 0x00000010, 0x20080010 },
 
-    /* nibble 6 */
+    { /* nibble 6 */
     0x00001000, 0x00000080, 0x00400080, 0x00400001,
     0x00401081, 0x00001001, 0x00001080, 0x00000000,
     0x00400000, 0x00400081, 0x00000081, 0x00401000,
@@ -129,9 +129,9 @@ static unsigned long des_SPtrans[8][64]={
     0x00000000, 0x00400081, 0x00400080, 0x00001080,
     0x00000081, 0x00001000, 0x00401081, 0x00400000,
     0x00401080, 0x00000001, 0x00001001, 0x00401081,
-    0x00400001, 0x00401080, 0x00401000, 0x00001001,
+    0x00400001, 0x00401080, 0x00401000, 0x00001001 },
 
-    /* nibble 7 */
+    { /* nibble 7 */
     0x08200020, 0x08208000, 0x00008020, 0x00000000,
     0x08008000, 0x00200020, 0x08200000, 0x08208020,
     0x00000020, 0x08000000, 0x00208000, 0x00008020,
@@ -147,10 +147,10 @@ static unsigned long des_SPtrans[8][64]={
     0x08208020, 0x00200000, 0x08200000, 0x08000020,
     0x00208000, 0x00008020, 0x08008020, 0x08200000,
     0x00000020, 0x08208000, 0x00208020, 0x00000000,
-    0x08000000, 0x08200020, 0x00008000, 0x00208020};
+    0x08000000, 0x08200020, 0x00008000, 0x00208020 }};
 
 static unsigned long des_skb[8][64]={
-    /* for C bits (numbered as per FIPS 46) 1 2 3 4 5 6 */
+    { /* for C bits (numbered as per FIPS 46) 1 2 3 4 5 6 */
     0x00000000,0x00000010,0x20000000,0x20000010,
     0x00010000,0x00010010,0x20010000,0x20010010,
     0x00000800,0x00000810,0x20000800,0x20000810,
@@ -166,8 +166,8 @@ static unsigned long des_skb[8][64]={
     0x00080020,0x00080030,0x20080020,0x20080030,
     0x00090020,0x00090030,0x20090020,0x20090030,
     0x00080820,0x00080830,0x20080820,0x20080830,
-    0x00090820,0x00090830,0x20090820,0x20090830,
-    /* for C bits (numbered as per FIPS 46) 7 8 10 11 12 13 */
+    0x00090820,0x00090830,0x20090820,0x20090830 },
+    { /* for C bits (numbered as per FIPS 46) 7 8 10 11 12 13 */
     0x00000000,0x02000000,0x00002000,0x02002000,
     0x00200000,0x02200000,0x00202000,0x02202000,
     0x00000004,0x02000004,0x00002004,0x02002004,
@@ -183,8 +183,8 @@ static unsigned long des_skb[8][64]={
     0x10000400,0x12000400,0x10002400,0x12002400,
     0x10200400,0x12200400,0x10202400,0x12202400,
     0x10000404,0x12000404,0x10002404,0x12002404,
-    0x10200404,0x12200404,0x10202404,0x12202404,
-    /* for C bits (numbered as per FIPS 46) 14 15 16 17 19 20 */
+    0x10200404,0x12200404,0x10202404,0x12202404 },
+    { /* for C bits (numbered as per FIPS 46) 14 15 16 17 19 20 */
     0x00000000,0x00000001,0x00040000,0x00040001,
     0x01000000,0x01000001,0x01040000,0x01040001,
     0x00000002,0x00000003,0x00040002,0x00040003,
@@ -200,8 +200,8 @@ static unsigned long des_skb[8][64]={
     0x08000200,0x08000201,0x08040200,0x08040201,
     0x09000200,0x09000201,0x09040200,0x09040201,
     0x08000202,0x08000203,0x08040202,0x08040203,
-    0x09000202,0x09000203,0x09040202,0x09040203,
-    /* for C bits (numbered as per FIPS 46) 21 23 24 26 27 28 */
+    0x09000202,0x09000203,0x09040202,0x09040203 },
+    { /* for C bits (numbered as per FIPS 46) 21 23 24 26 27 28 */
     0x00000000,0x00100000,0x00000100,0x00100100,
     0x00000008,0x00100008,0x00000108,0x00100108,
     0x00001000,0x00101000,0x00001100,0x00101100,
@@ -217,8 +217,8 @@ static unsigned long des_skb[8][64]={
     0x04020000,0x04120000,0x04020100,0x04120100,
     0x04020008,0x04120008,0x04020108,0x04120108,
     0x04021000,0x04121000,0x04021100,0x04121100,
-    0x04021008,0x04121008,0x04021108,0x04121108,
-    /* for D bits (numbered as per FIPS 46) 1 2 3 4 5 6 */
+    0x04021008,0x04121008,0x04021108,0x04121108 },
+    { /* for D bits (numbered as per FIPS 46) 1 2 3 4 5 6 */
     0x00000000,0x10000000,0x00010000,0x10010000,
     0x00000004,0x10000004,0x00010004,0x10010004,
     0x20000000,0x30000000,0x20010000,0x30010000,
@@ -234,8 +234,8 @@ static unsigned long des_skb[8][64]={
     0x00101000,0x10101000,0x00111000,0x10111000,
     0x00101004,0x10101004,0x00111004,0x10111004,
     0x20101000,0x30101000,0x20111000,0x30111000,
-    0x20101004,0x30101004,0x20111004,0x30111004,
-    /* for D bits (numbered as per FIPS 46) 8 9 11 12 13 14 */
+    0x20101004,0x30101004,0x20111004,0x30111004 },
+    { /* for D bits (numbered as per FIPS 46) 8 9 11 12 13 14 */
     0x00000000,0x08000000,0x00000008,0x08000008,
     0x00000400,0x08000400,0x00000408,0x08000408,
     0x00020000,0x08020000,0x00020008,0x08020008,
@@ -251,8 +251,8 @@ static unsigned long des_skb[8][64]={
     0x02000001,0x0A000001,0x02000009,0x0A000009,
     0x02000401,0x0A000401,0x02000409,0x0A000409,
     0x02020001,0x0A020001,0x02020009,0x0A020009,
-    0x02020401,0x0A020401,0x02020409,0x0A020409,
-    /* for D bits (numbered as per FIPS 46) 16 17 18 19 20 21 */
+    0x02020401,0x0A020401,0x02020409,0x0A020409 },
+    { /* for D bits (numbered as per FIPS 46) 16 17 18 19 20 21 */
     0x00000000,0x00000100,0x00080000,0x00080100,
     0x01000000,0x01000100,0x01080000,0x01080100,
     0x00000010,0x00000110,0x00080010,0x00080110,
@@ -268,8 +268,8 @@ static unsigned long des_skb[8][64]={
     0x00200200,0x00200300,0x00280200,0x00280300,
     0x01200200,0x01200300,0x01280200,0x01280300,
     0x00200210,0x00200310,0x00280210,0x00280310,
-    0x01200210,0x01200310,0x01280210,0x01280310,
-    /* for D bits (numbered as per FIPS 46) 22 23 24 25 27 28 */
+    0x01200210,0x01200310,0x01280210,0x01280310 },
+    { /* for D bits (numbered as per FIPS 46) 22 23 24 25 27 28 */
     0x00000000,0x04000000,0x00040000,0x04040000,
     0x00000002,0x04000002,0x00040002,0x04040002,
     0x00002000,0x04002000,0x00042000,0x04042000,
@@ -285,7 +285,7 @@ static unsigned long des_skb[8][64]={
     0x00000820,0x04000820,0x00040820,0x04040820,
     0x00000822,0x04000822,0x00040822,0x04040822,
     0x00002820,0x04002820,0x00042820,0x04042820,
-    0x00002822,0x04002822,0x00042822,0x04042822,
+    0x00002822,0x04002822,0x00042822,0x04042822 },
 };
 
 #define c2l(c,l)	(l =((unsigned long)(*((c)++)))    , \
@@ -349,7 +349,7 @@ static unsigned long des_skb[8][64]={
  * compiler and the achitecture.  gcc2 always seems to do well :-).
  * Inspired by Dana How <how@isl.stanford.edu>
  * DO NOT use the alternative version on machines with 8 byte longs.
- */
+ */ 
 #ifdef ALT_ECB
 #define D_ENCRYPT(L,R,S) \
 	u=((R^s[S  ])<<2);	\
@@ -383,9 +383,12 @@ static unsigned long des_skb[8][64]={
 
 static char shifts2[16]={0,0,1,1,1,1,1,1,0,1,1,1,1,1,1,0};
 
-static void des_set_key(key,schedule)
-     char *key;
-     unsigned long *schedule;
+static void des_set_key( char *, unsigned long * );
+static void des_encrypt( unsigned long *, unsigned long *, int );
+int _des_crypt( char *, unsigned, struct desparams * );
+
+static void
+des_set_key( char *key, unsigned long *schedule )
 {
     register unsigned long c,d,t,s;
     register unsigned char *in;
@@ -439,10 +442,8 @@ static void des_set_key(key,schedule)
 }
 
 
-static void des_encrypt(buf,schedule,encrypt)
-     unsigned long *buf;
-     char *schedule;
-     int encrypt;
+static void
+des_encrypt( unsigned long *buf, unsigned long *schedule, int encrypt )
 {
     register unsigned long l,r,t,u;
 #ifdef ALT_ECB
@@ -515,14 +516,12 @@ static void des_encrypt(buf,schedule,encrypt)
 }
 
 
-int _des_crypt(buf,len,desp)
-char *buf;
-unsigned len;
-struct desparams *desp;
+int
+_des_crypt( char *buf, unsigned len, struct desparams *desp )
 {
     unsigned long schedule[32];
-    register unsigned long tin0,tin1;
-    register unsigned long tout0,tout1,xor0,xor1;
+    register unsigned long tin0, tin1;
+    register unsigned long tout0, tout1, xor0, xor1;
     register unsigned char *in, *out;
     unsigned long tbuf[2];
     unsigned char *iv, *oiv;
@@ -534,8 +533,9 @@ struct desparams *desp;
     out=(unsigned char *)buf;
     oiv=iv=(unsigned char *)desp->des_ivec;
     
-    des_set_key(desp->des_key,schedule);
+    des_set_key(desp->des_key, schedule);
 
+	 tin0 = tin1 = 0;		/* For GCC */
     if (desp->des_dir == ENCRYPT) {
 	c2l(iv,tout0);
 	c2l(iv,tout1);
@@ -548,7 +548,7 @@ struct desparams *desp;
 	    }
 	    tbuf[0]=tin0;
 	    tbuf[1]=tin1;
-	    des_encrypt(tbuf,schedule,1);
+	    des_encrypt( tbuf, schedule, 1);
 	    tout0=tbuf[0];
 	    tout1=tbuf[1];
 	    l2c(tout0,out);
@@ -564,7 +564,7 @@ struct desparams *desp;
 	    c2l(in,tin1);
 	    tbuf[0]=tin0;
 	    tbuf[1]=tin1;
-	    des_encrypt(tbuf,schedule,0);
+	    des_encrypt( tbuf, schedule, 0);
  	    if (cbc_mode) {
 		tout0=tbuf[0]^xor0;
 		tout1=tbuf[1]^xor1;
